==> james-project-3.7.6-source-release.zip: james-project/server/mailet/mailetcontainer-api/src/main/java/org/apache/james/mailetcontainer/api/MatcherLoader.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.mailetcontainer.api;

import javax.mail.MessagingException;

import org.apache.mailet.Matcher;
import org.apache.mailet.MatcherConfig;

/**
 * Implementations of this interface are responsible for loading {@link Matcher}
 * instances
 */
public interface MatcherLoader {

    /**
     * Get a new {@link Matcher} for the given {@link MatcherConfig}. The
     * returned {@link Matcher} needs to be fully initialized, so the returned
     * instance is "read-to-use"
     *
     * @throws MessagingException
     *             if an error occurs
     */
    Matcher getMatcher(MatcherConfig config) throws MessagingException;

}

==> james-project-3.9.0-source-release.zip: james-project/server/mailet/mailetcontainer-api/src/main/java/org/apache/james/mailetcontainer/api/MatcherLoader.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.mailetcontainer.api;

import jakarta.mail.MessagingException;

import org.apache.mailet.Matcher;
import org.apache.mailet.MatcherConfig;

/**
 * Implementations of this interface are responsible for loading {@link Matcher}
 * instances
 */
public interface MatcherLoader {

    /**
     * Get a new {@link Matcher} for the given {@link MatcherConfig}. The
     * returned {@link Matcher} needs to be fully initialized, so the returned
     * instance is "read-to-use"
     *
     * @throws MessagingException
     *             if an error occurs
     */
    Matcher getMatcher(MatcherConfig config) throws MessagingException;

}
